@@ -1,7 +1,7 @@
 levenshtein.neighbors <-
-function(source, targets){
+function(xsource, targets){
     results<-list()
-    distances<-levenshtein.distance(source, targets)
+    distances<-levenshtein.distance(xsource, targets)
     for (distance in min(distances):max(distances)){
         results[distance]=list(names(which(distances==distance)))
     }
